import { type Token, BaseToken, WrapperToken } from "./token";
import { ChainIdTypeMap } from "./common/types";
export declare namespace Tokens {
    /**
     * The DAI stablecoin, available on Arbitrum, Avalanche, Binance Smart Chain, Ethereum, and Polygon.
     */
    const DAI: BaseToken;
    const BUSD: BaseToken;
    const USDC: BaseToken;
    const USDT: BaseToken;
    const UST: BaseToken;
    /**
     * ETH is the native currency ("gas token") for Ethereum, Optimism,
     * Boba, Arbitrum, and countless other chains
     * (though the four listed are the four currently supported by Synapse Protocol).
     * See {@link WETH} for a "wrapped" ERC20 variant of ETH.
     */
    const ETH: BaseToken;
    /**
     * nETH is a token involved in the bridge.
     */
    const NETH: BaseToken;
    const WETH: BaseToken;
    const WETHBEAM: BaseToken;
    const WETH_E: BaseToken;
    const AVWETH: BaseToken;
    const ONE_ETH: BaseToken;
    const FTM_ETH: BaseToken;
    const METIS_ETH: BaseToken;
    const SYN: BaseToken;
    /**
     * nUSD is a token involved in the bridge.
     */
    const NUSD: BaseToken;
    /**
     * AVAX is the native currency of Avalanche C-Chain.
     * See {@link WAVAX} for the "wrapped" ERC20 variant of this token.
     */
    const AVAX: BaseToken;
    const WAVAX: WrapperToken;
    /**
     * SYN_AVAX (synAVAX) is a "wrapped" ERC20 form of AVAX,
     * and is the supported output Token when bridging AVAX from
     * Avalanche C-Chain or Defi Kingdoms mainnet to Harmony.
     */
    const SYN_AVAX: BaseToken;
    const MULTI_AVAX: BaseToken;
    /**
     * MOVR is the native currency of the Moonriver chain.
     * See {@link WMOVR} for the "wrapped" ERC20 variant of this token.
     */
    const MOVR: BaseToken;
    const WMOVR: WrapperToken;
    /**
     * GAS_JEWEL is the native currency of the DeFi Kingdoms chain.
     * See {@link JEWEL} for the "wrapped" ERC20 variant of this token.
     */
    const GAS_JEWEL: BaseToken;
    /**
     * JEWEL is a "wrapped" ERC20 variant of {@link GAS_JEWEL}.
     * In the context of Synapse Protocol, JEWEL is primarily used for
     * bridging the native currency of the DeFi Kingdoms mainnet, {@link GAS_JEWEL},
     * to and from the Harmony and Avalanche networks.
     */
    const JEWEL: WrapperToken;
    /**
     * SYN_JEWEL ("synJewel") is an ERC20 Token used by Synapse Protocol to
     * bridge and "wrap" the native currency of the DeFi Kingdoms mainnet, {@link GAS_JEWEL},
     * to and from Avalanche C-Chain.
     *
     * synJEWEL is supported on Harmony as an "intermediate" token; for example, it is
     * possible to bridge {@link JEWEL} from Harmony to synJEWEL on Avalanche, and then
     * bridge synJEWEL to native {@link GAS_JEWEL} on the DeFi Kingdoms mainnet.
     */
    const SYN_JEWEL: BaseToken;
    const MULTIJEWEL: BaseToken;
    const XJEWEL: BaseToken;
    const GOHM: BaseToken;
    const HIGH: BaseToken;
    const JUMP: BaseToken;
    const DOG: BaseToken;
    const NFD: BaseToken;
    const FRAX: BaseToken;
    const SYN_FRAX: BaseToken;
    const SOLAR: BaseToken;
    const GMX: BaseToken;
    const NEWO: BaseToken;
    const SDT: BaseToken;
    const LUNA: BaseToken;
    const USDB: BaseToken;
    const mintBurnTokens: Token[];
    const isMintBurnToken: (token: Token) => boolean;
    const ChainGasTokensMap: ChainIdTypeMap<Token>;
    /**
     * Returns the native currency Token ("gas token") for a given chain, if
     * it's supported by Synapse Protocol.
     * @param chainId
     */
    const gasTokenForChain: (chainId: number) => Token | null;
    /**
     * Returns the "wrapper" Token for a given native currency Token ("gas token")
     * if such Token exists and is supported by Synapse Protocol.
     * @param gasToken
     */
    const gasTokenWrapper: (gasToken: Token) => Token | null;
    const AllTokens: Token[];
}
